/*
 * Copyright 2015 Luca Beltrame <lbeltrame@kde.org>
 *
 * This file is part of Danbooru Client.
 *
 * Danbooru Client is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Danbooru Client is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Danbooru Client. If not, see <http://www.gnu.org/licenses/>.
 */

// Qt

#include <QString>
#include <QPixmap>
#include <QUrl>

// Own

#include "danboorupost.h"

namespace Danbooru
{

DanbooruPost::DanbooruPost(QObject *parent): QObject(parent)
{
    m_pixmap = QPixmap();
    m_tags = QSet<QString>();
    m_height = 0;
    m_width = 0;
    m_url = QUrl();
    m_thumbnailUrl = QUrl();
    m_size = 0;
    m_rating = Questionable;
}

DanbooruPost::DanbooruPost(QVariantMap postData, QObject *parent):
    QObject(parent),
    m_pixmap(QPixmap())
{
    m_tags = postData.value("tags").value< QSet<QString> >();
    m_height = postData.value("height").toInt();
    m_width = postData.value("width").toInt();
    m_size = postData.value("size").toInt();
    m_url = postData.value("url").toUrl();
    m_thumbnailUrl = postData.value("thumbnailUrl").toUrl();
    m_sampleUrl = postData.value("sampleUrl").toUrl();
    m_rating = postData.value("rating").value<Danbooru::Rating>();
    
}

DanbooruPost::DanbooruPost(QXmlStreamAttributes &postData, QObject *parent):
    QObject(parent),
    m_pixmap(QPixmap())
{

}

bool DanbooruPost::operator==(const Danbooru::DanbooruPost &other)
{
    return m_url == other.m_url && m_id == other.m_id;
}

void DanbooruPost::setPixmap(const QPixmap &pixmap)
{
    m_pixmap = pixmap;
}

void DanbooruPost::setFileUrl(const QUrl &url) {
    if (url.isValid()) {
        m_url = url;
    }
}

void DanbooruPost::setSampleUrl(const QUrl &url) {
    if (url.isValid()) {
        m_sampleUrl = url;
    }
}

void DanbooruPost::setThumbnailUrl(const QUrl &url) {
    if (url.isValid()) {
        m_thumbnailUrl = url;
    }
}

const QString DanbooruPost::toString()
{
    QString display = QString("Danbooru Post with ID %1 and URL %2, width %3 height %4 ");
    display = display.arg(id()).arg(fileUrl().url()).arg(width()).arg(height());
    return display;
}

int DanbooruPost::id() const
{
    return m_id;
}

int DanbooruPost::height() const
{
    return m_height;
}

int DanbooruPost::width() const
{
    return m_width;
}

const QSet< QString > DanbooruPost::tags() const
{
    return m_tags;
}

const QUrl DanbooruPost::thumbnailUrl() const
{
    return m_thumbnailUrl;
}

const QUrl DanbooruPost::sampleUrl() const
{
    return m_sampleUrl;
}

QPixmap DanbooruPost::pixmap() const
{
    return m_pixmap;
}

int DanbooruPost::size() const
{
    return m_size;
}

const QUrl DanbooruPost::fileUrl() const
{
    return m_url;
}

Danbooru::Rating DanbooruPost::rating() const
{
    return m_rating;
}

} // namespace Danbooru

